globals [ nmbr-turtles-list j ]
turtles-own [ d sex paired p-c1 p-c2 p-i1 p-i2 C-th partner mate s a age ] 
patches-own [ K N C-i K-i ]

to setup
  clear-all
  
  ;setup patches
  ask patches [set K pxcor + 10]  
  
  ;setup turtles
  create-turtles nbrturtles [setxy random-xcor 0]
  set-default-shape turtles "dot"
  ask turtles [
    set p-c1 1
    set p-c2 1
    set p-i1 0
    set p-i2 0
    set paired 0
    ifelse random-float 1 > .5
    [set sex 1]  ; 1 = male
    [set sex 0]  ; 0 = female
    set age 1
  ]
      
   ;configure patches 
   ask patches [
     set N count turtles-here
     set C-i N
     set K-i K / 100
   ]
   
   set j 1  ;sets up continuous, looped time-control
   set #-Ctrls 0  ;sets number of controls to zero
   set nmbr-turtles-list []  ;creates list for storing #'s of turtles
     
end


to go  
    if count turtles = 0 [  stop ]
    control
    disperse
    reproduce
    do-plots
    tick
end


to manual-ctrl  ;control button (for demonstrations)
  let cpatch ( random 180 )
  let i  0
  while [ i < control-amt / 2]
  [
   ask turtles-on patch (cpatch - i) 0 [die]
   ask turtles-on patch (cpatch + i) 0 [die]
   set i i + 1
  ]
  
  set #-Ctrls #-Ctrls + 1
  
end



to control
  
  ;regulates the pest # control mechanism
  if pest#-ctrl [
  if count turtles > pest-thrsh
  [
    let cpatch ( random 180 )
    let i  0
    while [ i < control-amt / 2]
    [
     ask turtles-on patch (cpatch - i) 0 [die]
     ask turtles-on patch (cpatch + i) 0 [die]
     set i i + 1
    ] 
  
  set #-Ctrls #-Ctrls + 1  
  ]
  
  ]
  
  ;regulates the time control mechanism
  if time-ctrl
  [
    if ticks = ( j * control-interval )
    [
      let cpatch ( random 180 )
      let i  0
      while [ i < control-amt / 2]
      [
       ask turtles-on patch (cpatch - i) 0 [die]
       ask turtles-on patch (cpatch + i) 0 [die]
       set i i + 1
      ]
    
    set j ( j + 1 )
    set #-Ctrls #-Ctrls + 1
    
    ]   
  ]
end
  
  

to disperse  
  ask turtles [set age age + 1]
  ask turtles with [age = 4] [die]  ;sequencing agent death here prevents the saw-tooth population pattern
 
  ask turtles [
    if age = 2 [
    let tC-i [C-i] of patch-here  ;let reporter [var] of patch-here
    let tK-i [K-i] of patch-here
    set C-th (((p-c1 + p-c2) / 2) - ((p-i1 + p-i2) / 2) / tK-i)
    ifelse tC-i <= C-th
    [set d 0]
    [ifelse tC-i = 0 [set d 0][set d (1 - (1 / tC-i)*(C-th))]]
    
    let dispersal random-float 1
    if dispersal < d [
      let newpatch random 181
      setxy newpatch 0
    ]
    
    
    ;dispersal mortality
    let dm random-float 1
    if dm < dispersal-mortality [ die ]
    ]
  ]
end


to reproduce
  ask turtles [
    if age = 2 [
    if paired = 0 [
      set partner self
      set mate one-of turtles-here with [paired = 0]
      
      if not ([sex] of mate = [sex] of self) [
        let pc-1-offspring ( ([p-c1] of self + [p-c1] of mate) / 2 )
        let pc-2-offspring ( ([p-c2] of self + [p-c2] of mate) / 2 )
        let pi-1-offspring ( ([p-i1] of self + [p-i1] of mate) / 2 )
        let pi-2-offspring ( ([p-c2] of self + [p-c2] of mate) / 2 )
                
        ;limits the number of offspring to K
        let nmbroffspring random-Poisson avg-offspring
        let pK [K] of patch-here
        if ( nmbroffspring + count turtles-here ) > K
          [ set nmbroffspring K - count turtles-here ]
        
        
       
        hatch nmbroffspring [
          
          ;genetic mutation
          let mr random-float 1
          ifelse mr < mutation-rate 
          [
            set p-c1 random-float 1
            set p-c2 random-float 1
            set p-i1 random-float 1
            set p-i2 random-float 1
            set age 0
          ]
          [    
            set p-c1 pc-1-offspring
            set p-c2 pc-2-offspring
            set p-i1 pi-1-offspring
            set p-i2 pi-2-offspring
            set age 0
          ]
          
          ;offspring mortality
          let oK [K] of patch-here
          let oN [N] of patch-here
          set s ( oN / oK )
          
          let om random-float 1
          if om < s [ die ]
                   
          
        ]
        
        set paired 1         
        ask mate [set paired 1]
      ]
    ]
  ]
  ]
  
  ask patches [ set N count turtles-here ]  ;updates number of turtles on a patch
  set nmbr-turtles-list lput count turtles nmbr-turtles-list  ;stores count turtles in a list for analysis
  
  
end



to do-plots
  if count turtles > 0
  [
   set-current-plot "Average Dispersal Rate"
   plot mean [d] of turtles
  
   set-current-plot "Number Turtles"
   plot count turtles
   
  ]
end 
@#$#@#$#@
GRAPHICS-WINDOW
210
10
582
43
-1
0
2.0
1
10
1
1
1
0
1
1
1
0
180
0
0
0
0
1
ticks

BUTTON
20
24
84
57
Setup
setup
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
18
161
190
194
nbrturtles
nbrturtles
0
1000
300
1
1
NIL
HORIZONTAL

BUTTON
99
24
162
57
Go
go
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
18
207
190
240
dispersal-mortality
dispersal-mortality
0
1
0.1
.01
1
NIL
HORIZONTAL

PLOT
606
10
939
261
Average Dispersal Rate
time
avg d
0.0
10.0
0.0
1.0
true
false
PENS
"default" 1.0 0 -16777216 true

BUTTON
99
63
162
96
Go
go
T
1
T
OBSERVER
NIL
NIL
NIL
NIL

SLIDER
18
254
190
287
avg-offspring
avg-offspring
0
100
10
1
1
NIL
HORIZONTAL

PLOT
606
272
939
523
Number Turtles
time
nbr turtles
0.0
10.0
0.0
10.0
true
false
PENS
"default" 1.0 0 -16777216 true

SLIDER
18
300
190
333
mutation-rate
mutation-rate
0
1
0.1
.01
1
NIL
HORIZONTAL

SLIDER
267
111
439
144
control-amt
control-amt
1
25
15
2
1
NIL
HORIZONTAL

SLIDER
266
159
438
192
pest-thrsh
pest-thrsh
0
12000
10000
1
1
NIL
HORIZONTAL

SWITCH
452
136
556
169
time-ctrl
time-ctrl
1
1
-1000

SLIDER
266
219
438
252
control-interval
control-interval
0
100
50
1
1
NIL
HORIZONTAL

SWITCH
453
185
586
218
pest#-ctrl
pest#-ctrl
1
1
-1000

INPUTBOX
959
39
1029
99
#-Ctrls
0
1
0
Number

MONITOR
959
111
1030
156
# Turtles
count turtles
0
1
11

MONITOR
959
168
1093
213
Avg # Turtles
mean nmbr-turtles-list
2
1
11

BUTTON
99
107
171
140
Control
manual-ctrl
NIL
1
T
OBSERVER
NIL
NIL
NIL
NIL

MONITOR
958
226
1064
271
Median # Turtles
median nmbr-turtles-list
17
1
11

MONITOR
958
284
1048
329
Max # Turtles
max nmbr-turtles-list
17
1
11

MONITOR
958
342
1044
387
Min # Turtles
min nmbr-turtles-list
17
1
11

MONITOR
959
403
1077
448
Avg Dispersal Rate
mean [d] of turtles
2
1
11

@#$#@#$#@
WHAT IS IT?
-----------
This model looks at the effects of a "control" on agent populations.  Much like farmers spraying pesticides/herbicides to manage pest populations, the user sets a control management regiment to be used in the patch environment.  Agents also evolve an optimum dispersal rate for a given combination of controls.

The model is a modification of one described in The American Naturalist by Poethke et al. (2003).  There the author investigates the emergence of optimum dispersal rates for density-dependent and independent local extinction events.

Extension was conducted by David Shanafelt at Arizona State University as a semester project in AML591:  Agent-Based Modeling.


HOW IT WORKS
------------
Agents have a set age, sex, patch affiliation, and four genetic alleles on two genes that code for dispersal probability.  Ages vary from birth (0), juveniles (0-1), adults (2-3), and death (4).

Patches are characterized by each's carrying capacity, agent population size, and agent population density.

At each timestep adults may disperse and/or mate.  A dispersal threshold is calculated from an agent's genes.  That, in combination with the carrying capacity/population density of the current patch, determine whether an agent will disperse or not.  Agents have an equal probability of spreading to any patch on the environment.  However, there is a risk of agent death when dispersing (dispersal mortality).

Adult males and females on the same patch may mate once during each timestep.  They produce offspring given by a Poisson distribution with a mean set by the user (avg-offspring).  Offspring plus all present agents on a patch will never exceed a patch's carrying capacity.  If greater, the number of offspring will be limited to maximize the carrying capacity of the patch.  

Offspring are given an age = 0 and either the average gene combination of their parents or new values due to mutation.  And like dispersal mortality there is a density-dependent offspring mortality.


HOW TO USE IT
-------------
First, select the number of initial turtles, their average offspring, and dispersal and mutation rates from the sliders along the left side of the interface.  Then press "Setup" to initialize the environment and "Go" to begin the simulation.

Types of control management can be implemented at any time during a run.  Turning on time control (time-ctrl) will do a "management control" of user-controlled intensity (control-amt) every set timesteps (control-interval).  For instance, with time-ctrl = on, control-amt = 15, and control-interval = 50, every 50 ticks there will be a random block of fifteen patches that will have all turtles eliminated.

Pest number control implements a control when overall agent population numbers exceed a set threshold (pest-thrsh).

During a run, try pressing the "Control" button to see the effects of a control.  Agents are colored in the patch environment.  Notice the black spaces that form as agents are eliminated as well as drops in agent numbers.



THINGS TO TRY
-------------
See if you can find a "best" control regiment having the least number of controls required to maintain lower agent population levels.  Is time or pest number threshold a better management technique?  Or is the optimum a combination of the two?


NETLOGO FEATURES
----------------
let reporter [var] of patch-here

This allows one to use variables from a turtle or patch context in another (ex. a patch variable in an "ask turtles" statement).


CREDITS AND REFERENCES
----------------------
This model is a modification of one by Poethke et al. found in The American Naturalist:

Poethke, H. J., Hovestadt, T., Mitesser, O. 2003. Local Extinction and the Evolution of
Dispersal Rates: Causes and Correlations. The American Naturalist 161(4)631-640.
@#$#@#$#@
default
true
0
Polygon -7500403 true true 150 5 40 250 150 205 260 250

airplane
true
0
Polygon -7500403 true true 150 0 135 15 120 60 120 105 15 165 15 195 120 180 135 240 105 270 120 285 150 270 180 285 210 270 165 240 180 180 285 195 285 165 180 105 180 60 165 15

arrow
true
0
Polygon -7500403 true true 150 0 0 150 105 150 105 293 195 293 195 150 300 150

box
false
0
Polygon -7500403 true true 150 285 285 225 285 75 150 135
Polygon -7500403 true true 150 135 15 75 150 15 285 75
Polygon -7500403 true true 15 75 15 225 150 285 150 135
Line -16777216 false 150 285 150 135
Line -16777216 false 150 135 15 75
Line -16777216 false 150 135 285 75

bug
true
0
Circle -7500403 true true 96 182 108
Circle -7500403 true true 110 127 80
Circle -7500403 true true 110 75 80
Line -7500403 true 150 100 80 30
Line -7500403 true 150 100 220 30

butterfly
true
0
Polygon -7500403 true true 150 165 209 199 225 225 225 255 195 270 165 255 150 240
Polygon -7500403 true true 150 165 89 198 75 225 75 255 105 270 135 255 150 240
Polygon -7500403 true true 139 148 100 105 55 90 25 90 10 105 10 135 25 180 40 195 85 194 139 163
Polygon -7500403 true true 162 150 200 105 245 90 275 90 290 105 290 135 275 180 260 195 215 195 162 165
Polygon -16777216 true false 150 255 135 225 120 150 135 120 150 105 165 120 180 150 165 225
Circle -16777216 true false 135 90 30
Line -16777216 false 150 105 195 60
Line -16777216 false 150 105 105 60

car
false
0
Polygon -7500403 true true 300 180 279 164 261 144 240 135 226 132 213 106 203 84 185 63 159 50 135 50 75 60 0 150 0 165 0 225 300 225 300 180
Circle -16777216 true false 180 180 90
Circle -16777216 true false 30 180 90
Polygon -16777216 true false 162 80 132 78 134 135 209 135 194 105 189 96 180 89
Circle -7500403 true true 47 195 58
Circle -7500403 true true 195 195 58

circle
false
0
Circle -7500403 true true 0 0 300

circle 2
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240

cow
false
0
Polygon -7500403 true true 200 193 197 249 179 249 177 196 166 187 140 189 93 191 78 179 72 211 49 209 48 181 37 149 25 120 25 89 45 72 103 84 179 75 198 76 252 64 272 81 293 103 285 121 255 121 242 118 224 167
Polygon -7500403 true true 73 210 86 251 62 249 48 208
Polygon -7500403 true true 25 114 16 195 9 204 23 213 25 200 39 123

cylinder
false
0
Circle -7500403 true true 0 0 300

dot
false
0
Circle -7500403 true true 90 90 120

face happy
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 255 90 239 62 213 47 191 67 179 90 203 109 218 150 225 192 218 210 203 227 181 251 194 236 217 212 240

face neutral
false
0
Circle -7500403 true true 8 7 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Rectangle -16777216 true false 60 195 240 225

face sad
false
0
Circle -7500403 true true 8 8 285
Circle -16777216 true false 60 75 60
Circle -16777216 true false 180 75 60
Polygon -16777216 true false 150 168 90 184 62 210 47 232 67 244 90 220 109 205 150 198 192 205 210 220 227 242 251 229 236 206 212 183

fish
false
0
Polygon -1 true false 44 131 21 87 15 86 0 120 15 150 0 180 13 214 20 212 45 166
Polygon -1 true false 135 195 119 235 95 218 76 210 46 204 60 165
Polygon -1 true false 75 45 83 77 71 103 86 114 166 78 135 60
Polygon -7500403 true true 30 136 151 77 226 81 280 119 292 146 292 160 287 170 270 195 195 210 151 212 30 166
Circle -16777216 true false 215 106 30

flag
false
0
Rectangle -7500403 true true 60 15 75 300
Polygon -7500403 true true 90 150 270 90 90 30
Line -7500403 true 75 135 90 135
Line -7500403 true 75 45 90 45

flower
false
0
Polygon -10899396 true false 135 120 165 165 180 210 180 240 150 300 165 300 195 240 195 195 165 135
Circle -7500403 true true 85 132 38
Circle -7500403 true true 130 147 38
Circle -7500403 true true 192 85 38
Circle -7500403 true true 85 40 38
Circle -7500403 true true 177 40 38
Circle -7500403 true true 177 132 38
Circle -7500403 true true 70 85 38
Circle -7500403 true true 130 25 38
Circle -7500403 true true 96 51 108
Circle -16777216 true false 113 68 74
Polygon -10899396 true false 189 233 219 188 249 173 279 188 234 218
Polygon -10899396 true false 180 255 150 210 105 210 75 240 135 240

house
false
0
Rectangle -7500403 true true 45 120 255 285
Rectangle -16777216 true false 120 210 180 285
Polygon -7500403 true true 15 120 150 15 285 120
Line -16777216 false 30 120 270 120

leaf
false
0
Polygon -7500403 true true 150 210 135 195 120 210 60 210 30 195 60 180 60 165 15 135 30 120 15 105 40 104 45 90 60 90 90 105 105 120 120 120 105 60 120 60 135 30 150 15 165 30 180 60 195 60 180 120 195 120 210 105 240 90 255 90 263 104 285 105 270 120 285 135 240 165 240 180 270 195 240 210 180 210 165 195
Polygon -7500403 true true 135 195 135 240 120 255 105 255 105 285 135 285 165 240 165 195

line
true
0
Line -7500403 true 150 0 150 300

line half
true
0
Line -7500403 true 150 0 150 150

pentagon
false
0
Polygon -7500403 true true 150 15 15 120 60 285 240 285 285 120

person
false
0
Circle -7500403 true true 110 5 80
Polygon -7500403 true true 105 90 120 195 90 285 105 300 135 300 150 225 165 300 195 300 210 285 180 195 195 90
Rectangle -7500403 true true 127 79 172 94
Polygon -7500403 true true 195 90 240 150 225 180 165 105
Polygon -7500403 true true 105 90 60 150 75 180 135 105

plant
false
0
Rectangle -7500403 true true 135 90 165 300
Polygon -7500403 true true 135 255 90 210 45 195 75 255 135 285
Polygon -7500403 true true 165 255 210 210 255 195 225 255 165 285
Polygon -7500403 true true 135 180 90 135 45 120 75 180 135 210
Polygon -7500403 true true 165 180 165 210 225 180 255 120 210 135
Polygon -7500403 true true 135 105 90 60 45 45 75 105 135 135
Polygon -7500403 true true 165 105 165 135 225 105 255 45 210 60
Polygon -7500403 true true 135 90 120 45 150 15 180 45 165 90

sheep
false
0
Rectangle -7500403 true true 151 225 180 285
Rectangle -7500403 true true 47 225 75 285
Rectangle -7500403 true true 15 75 210 225
Circle -7500403 true true 135 75 150
Circle -16777216 true false 165 76 116

square
false
0
Rectangle -7500403 true true 30 30 270 270

square 2
false
0
Rectangle -7500403 true true 30 30 270 270
Rectangle -16777216 true false 60 60 240 240

star
false
0
Polygon -7500403 true true 151 1 185 108 298 108 207 175 242 282 151 216 59 282 94 175 3 108 116 108

target
false
0
Circle -7500403 true true 0 0 300
Circle -16777216 true false 30 30 240
Circle -7500403 true true 60 60 180
Circle -16777216 true false 90 90 120
Circle -7500403 true true 120 120 60

tree
false
0
Circle -7500403 true true 118 3 94
Rectangle -6459832 true false 120 195 180 300
Circle -7500403 true true 65 21 108
Circle -7500403 true true 116 41 127
Circle -7500403 true true 45 90 120
Circle -7500403 true true 104 74 152

triangle
false
0
Polygon -7500403 true true 150 30 15 255 285 255

triangle 2
false
0
Polygon -7500403 true true 150 30 15 255 285 255
Polygon -16777216 true false 151 99 225 223 75 224

truck
false
0
Rectangle -7500403 true true 4 45 195 187
Polygon -7500403 true true 296 193 296 150 259 134 244 104 208 104 207 194
Rectangle -1 true false 195 60 195 105
Polygon -16777216 true false 238 112 252 141 219 141 218 112
Circle -16777216 true false 234 174 42
Rectangle -7500403 true true 181 185 214 194
Circle -16777216 true false 144 174 42
Circle -16777216 true false 24 174 42
Circle -7500403 false true 24 174 42
Circle -7500403 false true 144 174 42
Circle -7500403 false true 234 174 42

turtle
true
0
Polygon -10899396 true false 215 204 240 233 246 254 228 266 215 252 193 210
Polygon -10899396 true false 195 90 225 75 245 75 260 89 269 108 261 124 240 105 225 105 210 105
Polygon -10899396 true false 105 90 75 75 55 75 40 89 31 108 39 124 60 105 75 105 90 105
Polygon -10899396 true false 132 85 134 64 107 51 108 17 150 2 192 18 192 52 169 65 172 87
Polygon -10899396 true false 85 204 60 233 54 254 72 266 85 252 107 210
Polygon -7500403 true true 119 75 179 75 209 101 224 135 220 225 175 261 128 261 81 224 74 135 88 99

wheel
false
0
Circle -7500403 true true 3 3 294
Circle -16777216 true false 30 30 240
Line -7500403 true 150 285 150 15
Line -7500403 true 15 150 285 150
Circle -7500403 true true 120 120 60
Line -7500403 true 216 40 79 269
Line -7500403 true 40 84 269 221
Line -7500403 true 40 216 269 79
Line -7500403 true 84 40 221 269

x
false
0
Polygon -7500403 true true 270 75 225 30 30 225 75 270
Polygon -7500403 true true 30 75 75 30 270 225 225 270

@#$#@#$#@
NetLogo 4.1.1
@#$#@#$#@
@#$#@#$#@
@#$#@#$#@
<experiments>
  <experiment name="Standardization" repetitions="500" runMetricsEveryStep="false">
    <setup>setup</setup>
    <go>go</go>
    <timeLimit steps="1000"/>
    <metric>count turtles</metric>
    <metric>mean nmbr-turtles-list</metric>
    <metric>median nmbr-turtles-list</metric>
    <metric>max nmbr-turtles-list</metric>
    <metric>min nmbr-turtles-list</metric>
    <metric>#-Ctrls</metric>
    <metric>mean [d] of turtles</metric>
    <enumeratedValueSet variable="pest-thrsh">
      <value value="10000"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-interval">
      <value value="50"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="avg-offspring">
      <value value="10"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="control-amt">
      <value value="20"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="nbrturtles">
      <value value="300"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="#-Ctrls">
      <value value="0"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="pest#-ctrl">
      <value value="false"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="dispersal-mortality">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="mutation-rate">
      <value value="0.1"/>
    </enumeratedValueSet>
    <enumeratedValueSet variable="time-ctrl">
      <value value="false"/>
    </enumeratedValueSet>
  </experiment>
</experiments>
@#$#@#$#@
@#$#@#$#@
default
0.0
-0.2 0 1.0 0.0
0.0 1 1.0 0.0
0.2 0 1.0 0.0
link direction
true
0
Line -7500403 true 150 150 90 180
Line -7500403 true 150 150 210 180

@#$#@#$#@
0
@#$#@#$#@
